"use client";

import { useState } from "react";

import { ShoppingCart } from "lucide-react";
import { useSession } from "next-auth/react";
import { useTranslations } from "next-intl";
import { toast } from "sonner";

import { useRouter } from "@/i18n/routing";
import { handleAddToCartAction } from "@/servers/actions/add-to-cart-action";

import ShinyButton from "../ui/shiny-button";

function AddToCart({ product_id }: { product_id: number }) {
	const t = useTranslations();

	const [loading, setLoading] = useState(false);
	const { status } = useSession();
	const router = useRouter();

	const click = async () => {
		if (status === "unauthenticated") router.push("/login");
		else {
			setLoading(true);
			const sendReq = await handleAddToCartAction(product_id);

			setLoading(false);

			if (sendReq.success) toast.success(t("AddedToCart"));
			else toast.error(t("ErrorWhenAddingToCart"));
		}
	};

	return (
		<ShinyButton
			disabled={loading}
			onClick={click}
			className="flex flex-row flex-nowrap items-center gap-3 rounded-md bg-[#2895c8]"
		>
			<p className="text-custom-background-light">
				{loading ? t("Loading") : t("AddToCart")}
			</p>
			<ShoppingCart color="#fafafa" />
		</ShinyButton>
	);
}

export default AddToCart;
